@@ -23,6 +23,10 @@
 
 using namespace std;
 
+class PreTree;
+class Sampler;
+class ResponseCtg;
+
 /**
    @brief Rank and sample-counts associated with sampled rows.
 
@@ -85,8 +89,6 @@ public:
    @brief Leaves are indexed by their numbering within the tree.
  */
 struct Leaf {
-  const bool thin; // EXIT.
-
   // Training only:
   vector<IndexT> indexCresc; ///< Sample indices within leaves.
   vector<IndexT> extentCresc; ///< Index extent, per leaf.
@@ -100,8 +102,7 @@ struct Leaf {
 
      @param Sampler conveys observation count, to set static packing parameters.
    */
-  static unique_ptr<Leaf> train(IndexT nObs,
-				bool thin);
+  static unique_ptr<Leaf> train(IndexT nObs);
 
   
   /**
@@ -113,8 +114,7 @@ struct Leaf {
 
      @param index gives sample positions.
   */
-  static unique_ptr<Leaf> predict(const class Sampler* sampler,
-				  bool thin,
+  static unique_ptr<Leaf> predict(const Sampler* sampler,
 				  vector<vector<size_t>> extent,
 				  vector<vector<vector<size_t>>> index);
 
@@ -122,14 +122,13 @@ struct Leaf {
   /**
      @brief Training constructor:  crescent structures only.
    */
-  Leaf(bool thin_);
-
+  Leaf();
 
+  
   /**
      @brief Post-training constructor:  fixed maps passed in.
    */
-  Leaf(const class Sampler* sampler,
-       bool thin_,
+  Leaf(const Sampler* sampler,
        vector<vector<size_t>> extent_,
        vector<vector<vector<size_t>>> index_);
 
@@ -139,6 +138,30 @@ struct Leaf {
    */
   ~Leaf();
 
+
+  static Leaf unpack(const Sampler* sampler,
+		     const double extent_[],
+		     const double index_[]);
+
+
+  static vector<vector<size_t>> unpackExtent(const Sampler* sampler,
+					     const double extentNum[]);
+
+
+  static vector<vector<vector<size_t>>> unpackIndex(const Sampler* sampler,
+					     const vector<vector<size_t>>& extent,
+					     const double numVal[]);
+
+
+  /**
+     @brief Indicates whether post-training leaf is empty.
+     
+     @return true iff the index vectors are unpopulated.
+   */
+  bool empty() const {
+    return extent.empty();
+  }
+
   
   /**
      @brief Copies terminal contents, if 'noLeaf' not specified.
@@ -146,8 +169,7 @@ struct Leaf {
      Training caches leaves in order of production.  Depth-first
      leaf numbering requires that the sample maps be reordered.
    */
-  void consumeTerminals(const class PreTree* pretree,
-			const struct SampleMap& smTerminal);
+  void consumeTerminals(const PreTree* pretree);
 
 
   /**
@@ -157,8 +179,8 @@ struct Leaf {
 
      @return 3-d vector category counts, indexed by tree/leaf/ctg.
    */
-  vector<vector<vector<size_t>>> countLeafCtg(const class Sampler* sampler,
-					      const class ResponseCtg* response) const;
+  vector<vector<vector<size_t>>> countLeafCtg(const Sampler* sampler,
+					      const ResponseCtg* response) const;
 
 
   /**
@@ -168,7 +190,7 @@ struct Leaf {
 
      @return 3-d mapping as described.
    */
-  vector<vector<vector<RankCount>>> alignRanks(const class Sampler* sampler,
+  vector<vector<vector<RankCount>>> alignRanks(const Sampler* sampler,
 					       const vector<IndexT>& obs2Rank) const;
 
 
