@@ -1,4 +1,4 @@
-// Copyright (C)  2012-2023   Mark Seligman
+// Copyright (C)  2012-2024   Mark Seligman
 //
 // This file is part of RboristBase.
 //
@@ -31,6 +31,12 @@
 using namespace Rcpp;
 
 
+#include<memory>
+using namespace std;
+
+struct SamplerBridge;
+class Predict;
+
 /**
    @brief Prediction with separate test vector.
 
@@ -45,10 +51,10 @@ using namespace Rcpp;
    @return wrapped predict object.
  */
 RcppExport SEXP predictRcpp(const SEXP sFrame,
-			    const SEXP sTrain,
-			    const SEXP sSampler,
-			    const SEXP sYTest,
-			    const SEXP sArgs);
+		 const SEXP sTrain,
+		 const SEXP sSampler,
+		 const SEXP sYTest,
+		 const SEXP sArgs);
 
 
 /**
@@ -57,43 +63,66 @@ RcppExport SEXP predictRcpp(const SEXP sFrame,
    Paramaters as with predictRcpp.
  */
 RcppExport SEXP validateRcpp(const SEXP sFrame,
-			     const SEXP sTrain,
-			     const SEXP sSampler,
-			     const SEXP sArgs);
+		  const SEXP sTrain,
+		  const SEXP sSampler,
+		  const SEXP sArgs);
 
 
 /**
-   @brief Bridge-variant PredictBridge pins unwrapped front-end structures.
+   @bridge Prediction through unwrapped PredictBridge object.
  */
-struct PBRf {
-
-  static List predictCtg(const List& lDeframe,
-			 const List& lTrain,
-			 const List& lSampler,
-			 const SEXP sYTest,
-			 const List& lArgs);
+struct PredictR {
+  static const string strQuantVec;
+  static const string strImpPermute;
+  static const string strIndexing;
+  static const string strBagging;
+  static const string strTrapUnobserved;
+  static const string strNThread;
+  static const string strCtgProb;
 
 
   /**
-     @brief Prediction for regression.  Parameters as above.
+     @brief Drives prediction according to response type.
+   */
+  static List predict(const List& lDeframe,
+		      const List& lTrain,
+		      const List& lSampler,
+		      const List& lArgs,
+		      const SEXP sYTest);
+
+
+  /**
+     @brief Instantiates core classification object and summarizes.
+
+     @return wrapped prediction.
+   */
+  static List predictCtg(const List& lDeframe,
+			 const List& lSampler,
+			 const SamplerBridge& samplerBridge,
+			 struct ForestBridge& forestBridge,
+			 const SEXP sYTest);
+
+
+  /**
+     @brief Instantiates core regression object and summarizes.
+
+     @return wrapped prediction.
    */
   static List predictReg(const List& lDeframe,
-                         const List& lTrain,
-			 const List& lSampler,
-                         const SEXP sYTest,
-			 const List& lArgs);
+			 const SamplerBridge& samplerBridge,
+			 struct ForestBridge& forestBridge,
+			 const SEXP sYTest);
+
 
-  
   /**
-     @brief Unwraps regression data structurs and moves to box.
+     @brief Per-invocation initialization of core static values.
 
-     @return unique pointer to bridge-variant PredictBridge. 
+     Algorithm-specific implementation included by configuration
+     script.
+
+     @retun implicit R_NilValue.
    */
-  static struct PredictRegBridge unwrapReg(const List& lDeframe,
-					   const List& lTrain,
-					   const List& lSampler,
-					   const SEXP sYTest,
-					   const List& lArgs);
+  static void initPerInvocation(const List& lArgs);
 
 
   /**
@@ -104,21 +133,10 @@ struct PBRf {
   List predict(SEXP sYTest,
                const vector<double>& quantile) const;
 
-  /**
-     @brief Unwraps regression data structurs and moves to box.
-
-     @return unique pointer to bridge-variant PredictBridge. 
-   */
-  static struct PredictCtgBridge unwrapCtg(const List& lDeframe,
-						       const List& lTrain,
-						       const List& lSampler,
-						       const SEXP sYTest,
-						       const List& lArgs);
-
 
   static List summary(const List& lDeframe,
 		      SEXP sYTest,
-                      const struct PredictRegBridge& pBridge);
+                      const struct PredictRegBridge* pBridge);
 
 
   /**
@@ -128,23 +146,23 @@ struct PBRf {
 
      @return transposed core matrix if quantiles requested, else empty matrix.
   */
-  static NumericMatrix getQPred(const struct PredictRegBridge& pBridge);
+  static NumericMatrix getQPred(const struct PredictRegBridge* pBridge);
 
 
-  static List getPrediction(const PredictRegBridge& pBridge);
+  static List getPrediction(const PredictRegBridge* pBridge);
 
 
-  static NumericMatrix getIndices(const struct PredictRegBridge& pBridge);
+  static NumericMatrix getIndices(const struct PredictRegBridge* pBridge);
 
   
   /**
      @param varTest is the variance of the test vector.
    */  
-  static List getValidation(const PredictRegBridge& pBridge,
+  static List getValidation(const PredictRegBridge* pBridge,
 			    const NumericVector& yTestFE);
   
 
-  static List getImportance(const struct PredictRegBridge& pBridge,
+  static List getImportance(const struct PredictRegBridge* pBridge,
 			    const NumericVector& yTestFE,
 			    const CharacterVector& predNames);
 
@@ -156,13 +174,6 @@ private:
    */
   static List predictReg(SEXP sYTest);
 
-  /**
-     @brief Instantiates core PredictRf object, driving prediction.
-
-     @return wrapped prediction.
-   */
-  static List predictCtg(SEXP sYTest, const List& lTrain, const List& sFrame);
-
 
   /**
      @return regression test vector suitable for core.
@@ -188,7 +199,7 @@ struct LeafRegRf {
 
   static List predict(const List &list,
                       SEXP sYTest,
-                      class Predict *predict);
+                      Predict *predict);
 };
 
   
@@ -199,7 +210,7 @@ struct LeafCtgRf {
   static List predict(const List &list,
 		      SEXP sYTest,
 		      const List &signature,
-		      class Predict *predict,
+		      Predict *predict,
 		      bool doProb);
   /**
      @param sYTest is the one-based test vector, possibly null.
@@ -210,11 +221,11 @@ struct LeafCtgRf {
   */
   static List summary(const List& lDeframe,
 		      const List& lSampler,
-                      const struct PredictCtgBridge& pBridge,
+                      const struct PredictCtgBridge* pBridge,
                       SEXP sYTest);
 
 
-  static NumericMatrix getIndices(const struct PredictCtgBridge& pBridge);
+  static NumericMatrix getIndices(const struct PredictCtgBridge* pBridge);
 
   
   /**
@@ -225,7 +236,7 @@ struct LeafCtgRf {
 
      @return matrix of predicted categorical responses, by row.
   */
-  static IntegerMatrix getCensus(const PredictCtgBridge& pBridge,
+  static IntegerMatrix getCensus(const PredictCtgBridge* pBridge,
                                  const CharacterVector& levelsTrain,
                                  const CharacterVector& rowNames);
 
@@ -235,12 +246,12 @@ struct LeafCtgRf {
 
      @return probability matrix if requested, otherwise empty matrix.
   */
-  static NumericMatrix getProb(const PredictCtgBridge& pBridge,
+  static NumericMatrix getProb(const PredictCtgBridge* pBridge,
                                const CharacterVector& levelsTrain,
                                const CharacterVector &rowNames);
 
   
-  static List getPrediction(const PredictCtgBridge& pBridge,
+  static List getPrediction(const PredictCtgBridge* pBridge,
 			    const CharacterVector& levelsTrain,
 			    const CharacterVector& ctgNames);
 };
@@ -250,15 +261,15 @@ struct LeafCtgRf {
    @brief Internal back end-style vectors cache annotations for
    per-tree access.
  */
-struct TestCtg {
+struct TestCtgR {
   const CharacterVector levelsTrain;
   const CharacterVector levels;
   const IntegerVector test2Merged;
   const vector<unsigned int> yTestZero;
   const unsigned int ctgMerged;
 
-  TestCtg(const IntegerVector& yTest,
-          const CharacterVector &levelsTrain_);
+  TestCtgR(const IntegerVector& yTest,
+          const CharacterVector& levelsTrain_);
 
   
   /**
@@ -277,10 +288,10 @@ struct TestCtg {
   IntegerVector mergeLevels(const CharacterVector& levelsTest);
 
 
-  List getValidation(const PredictCtgBridge& pBridge);
+  List getValidation(const PredictCtgBridge* pBridge);
 
 
-  List getImportance(const PredictCtgBridge& pBridge,
+  List getImportance(const PredictCtgBridge* pBridge,
 		     const CharacterVector& predNames);
 
   
@@ -289,7 +300,7 @@ struct TestCtg {
 
      @param pBridge is the bridge handle.
   */
-  NumericVector getMisprediction(const struct PredictCtgBridge& pBridge) const;
+  NumericVector getMisprediction(const struct PredictCtgBridge* pBridge) const;
   
 
 /**
@@ -302,17 +313,17 @@ struct TestCtg {
 
    @return numeric matrix to accommodate wide count values.
  */
-  NumericMatrix getConfusion(const PredictCtgBridge& pBridge,
+  NumericMatrix getConfusion(const PredictCtgBridge* pBridge,
 			     const CharacterVector& levelsTrain) const;
 
 
 
-  NumericMatrix mispredPermuted(const PredictCtgBridge& pBridge,
-				const CharacterVector& predNames) const;
+  List mispredPermuted(const PredictCtgBridge* pBridge,
+		       const CharacterVector& predNames) const;
 
 
 
-  NumericVector oobErrPermuted(const PredictCtgBridge& pBridge,
+  NumericMatrix oobErrPermuted(const PredictCtgBridge* pBridge,
 			       const CharacterVector& predNames) const;
 };
 
