@@ -22,28 +22,19 @@
 #include <vector>
 
 /**
-   @brief Single node type for regression and classification.
-
-   For simplicity, regression and classification variants are distinguished
-   only by method name and not by subtype.  The only distinction is the
-   value (and interpretation) of the 'ctg' field.  Care should be taken
-   to call the appropriate method, as 'ctg' is only used as a packing
-   parameter (with value zero) in the case of regression.  Subtyping seems
-   to complicate the code needlessly, with a per-tree size savings of only
-   'nSamp' * sizeof(uint).
+   @brief Container for compressed sampled response.
  */
-
 class SampleNux {
-  static unsigned int ctgBits; // Pack:  nonzero iff categorical.
+  static unsigned int ctgBits; ///< Pack:  nonzero iff categorical.
   static unsigned int ctgMask;
-  static unsigned int multMask; // Masks bits not used to encode multiplicity.
-  static unsigned int rightBits; // # bits to shift for left-most value.
-  static unsigned int rightMask; // Mask bits not used by multiplicity, ctg.
+  static unsigned int multMask; ///< Masks bits not used to encode multiplicity.
+  static unsigned int rightBits; ///< # bits to shift for left-most value.
+  static unsigned int rightMask; ///< Mask bits not used by multiplicity, ctg.
 
   // Integer-sized container is likely overkill:  typically << #rows,
   // although sample weighting might yield run sizes approaching #rows.
-  PackedT packed; // Packed sample count, ctg.
-  double ySum; // Sum of values selected:  sample-count * y-value.
+  PackedT packed; ///< Packed sample count, ctg.
+  double ySum; ///< Sum of values selected:  sample-count * y-value.
   
  public:
 
@@ -86,7 +77,7 @@ class SampleNux {
 
      @return sample count.
    */
-  inline IndexT getSCount() const {
+  IndexT getSCount() const {
     return (packed >> ctgBits) & multMask;
   }
 
@@ -98,7 +89,7 @@ class SampleNux {
 
      @return sample sum.
   */
-  inline double refCtg(PredictorT& ctg) const {
+  double refCtg(PredictorT& ctg) const {
     ctg = getCtg();
     return getYSum();
   }
@@ -107,7 +98,7 @@ class SampleNux {
   /**
      @brief Accessor for packed sCount/ctg member.
    */
-  inline auto getRight() const {
+  auto getRight() const {
     return packed & rightMask;
   }
 
@@ -117,7 +108,7 @@ class SampleNux {
 
      @return sum of y-values for sample.
    */
-  inline double getYSum() const {
+  double getYSum() const {
     return ySum;
   }
 
@@ -127,14 +118,27 @@ class SampleNux {
 
      @return response cardinality.
    */
-  inline PredictorT getCtg() const {
+  PredictorT getCtg() const {
     return packed & ctgMask;
   }
 
 
-  inline auto getDelRow() const {
+  auto getDelRow() const {
     return packed >> rightBits;
   }
+
+
+  /**
+     @brief Decrements sum value.
+
+     @param decr is the per-sample amount to decrement.
+     
+     @return decremented sum value.
+   */
+  double decrementSum(double decr) {
+    ySum -= decr * getSCount();
+    return ySum;
+  }
 };
 
 
