@@ -25,12 +25,6 @@ TrainBridge::TrainBridge(unique_ptr<RLEFrame> rleFrame, double autoCompress, boo
 TrainBridge::~TrainBridge() = default;
 
 
-vector<PredictorT> TrainBridge::getPredMap() const {
-  vector<PredictorT> predMap(frame->getPredMap());
-  return predMap;
-}
-
-
 void TrainBridge::init(unsigned int nPred) {
   FETrain::initDecNode(nPred);
 }
@@ -89,11 +83,6 @@ void TrainBridge::initNodeScorer(const string& scorer) {
 }
 
 
-void TrainBridge::initOmp(unsigned int nThread) {
-  FETrain::initOmp(nThread);
-}
-
-
 void TrainBridge::initSplit(unsigned int minNode,
                             unsigned int totLevels,
                             double minRatio,
